@@ -74,7 +74,7 @@ class Processor:
                     if self.verbose:
                         logger.info("File '{output_path}' not changed, skipping")
                     return True
-                elif input_mtime > output_mtime:
+                elif output_mtime > input_mtime:
                     logger.warning(f"Destination file '{output_path}' newer than input, skipping")
                     return True
         else:
@@ -120,11 +120,15 @@ class Processor:
                 if written != len(processed_content):
                     logger.warning(f"Partially written output ({written} of {len(processed_content)} bytes).")
                     return False
-                input_mtime_mod = time.mktime(input_mtime.timetuple())
-                os.utime(output_path, (input_mtime_mod, input_mtime_mod))
         except Exception as err:
             logger.warning(f"Could not write data to output file '{output_path}': {err}.")
             return False
+        try:
+            input_mtime_mod = time.mktime(input_mtime.timetuple())
+            os.utime(output_path, (input_mtime_mod, input_mtime_mod))
+        except Exception as err:
+            logger.warning(f"Could not correct modify date of output file '{output_path}': {err}.")
+            return False
         # All went well, go home happy!
         return True
 
